## 股票账户开户数据

接口：stk_account

描述：获取股票账户开户数据，统计周期为一周

积分：600积分可调取，具体请参阅积分获取办法 

注：此数据官方已经停止更新。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 统计周期 |
| weekly_new | float | Y | 本周新增（万） |
| total | float | Y | 期末总账户数（万） |
| weekly_hold | float | Y | 本周持仓账户数（万） |
| weekly_trade | float | Y | 本周参与交易账户数（万） |

接口使用

```python
pro = ts.pro_api()

df = pro.stk_account(start_date='20180101', end_date='20181231')
```

数据示例

```python
date      weekly_new     total weekly_hold weekly_trade
0   20181228       20.81  14650.44        None         None
```

数据说明：从2017年2月10日开始，中国证券登记结算公司停止了发布本周持仓账户数和本周交易账户数；另外，2015年5月8日之前的数据结构也不同，具体请参阅股票开户旧数据接口。